==> haskell-filtrable-0.1.5.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filtrable
version:              0.1.5.0
visibility:           public
id:                   filtrable-0.1.5.0-FO0NyjZBh8yFiMRoT1vvlt
key:                  filtrable-0.1.5.0-FO0NyjZBh8yFiMRoT1vvlt
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  a307afabf532131b57e5f1e0fd205085
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/filtrable-0.1.5.0
hs-libraries:         HSfiltrable-0.1.5.0-FO0NyjZBh8yFiMRoT1vvlt
depends:              base-4.14.1.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filtrable-0.1.5.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filtrable
version:              0.1.5.0
visibility:           public
id:                   filtrable-0.1.5.0-J08v63GRaCsGKcWnSJZ81h
key:                  filtrable-0.1.5.0-J08v63GRaCsGKcWnSJZ81h
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  abb730a8cce7a3c4245178bb0b691507
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/filtrable-0.1.5.0
hs-libraries:         HSfiltrable-0.1.5.0-J08v63GRaCsGKcWnSJZ81h
depends:              base-4.14.1.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
